@@ -15,21 +15,21 @@ class rcmd(genlmsg):
     Message class that will be used to communicate
     with the kernel module
     '''
-    nla_map = (('RLINK_ATTR_UNSPEC', 'none'),
-               ('RLINK_ATTR_DATA', 'asciiz'),
-               ('RLINK_ATTR_LEN', 'uint32'))
+
+    nla_map = (
+        ('RLINK_ATTR_UNSPEC', 'none'),
+        ('RLINK_ATTR_DATA', 'asciiz'),
+        ('RLINK_ATTR_LEN', 'uint32'),
+    )
 
 
 class Rlink(GenericNetlinkSocket):
-
     def send_data(self, data):
         msg = rcmd()
         msg['cmd'] = RLINK_CMD_REQ
         msg['version'] = 1
         msg['attrs'] = [('RLINK_ATTR_DATA', data)]
-        ret = self.nlm_request(msg,
-                               self.prid,
-                               msg_flags=NLM_F_REQUEST)[0]
+        ret = self.nlm_request(msg, self.prid, msg_flags=NLM_F_REQUEST)[0]
         return ret.get_attr('RLINK_ATTR_LEN')
 
 
