@@ -1,4 +1,9 @@
 '''
+:test:argv:testing
+:test:argv:secret
+:test:environ:RADIUS_SERVER=127.0.0.1
+:test:environ:RADIUS_SECRET=secret
+
 An example of using RADIUS authentication with NDB.
 
 In order to run the example you can setup a FreeRADIUS server::
